@@ -25,7 +25,6 @@ import platform
 import re
 import shutil
 import sys
-import tempfile
 from concurrent.futures.thread import ThreadPoolExecutor
 from hashlib import sha256
 from importlib import import_module
@@ -257,7 +256,6 @@ class Client(Methods):
         self.rnd_id = MsgId
 
         self.parser = Parser(self)
-        self.parse_mode = enums.ParseMode.DEFAULT
 
         self.session = None
 
@@ -271,8 +269,7 @@ class Client(Methods):
 
         self.disconnect_handler = None
 
-        # Username used for mentioned bot commands, e.g.: /start@usernamebot
-        self.username = None
+        self.me: Optional[User] = None
 
         self.message_cache = Cache(10000)
 
@@ -593,21 +590,24 @@ class Client(Methods):
         else:
             # Needed for migration from storage v2 to v3
             if not await self.storage.api_id():
-                while True:
-                    try:
-                        value = int(await ainput("Enter the api_id part of the API key: "))
+                if self.api_id:
+                    await self.storage.api_id(self.api_id)
+                else:
+                    while True:
+                        try:
+                            value = int(await ainput("Enter the api_id part of the API key: "))
 
-                        if value <= 0:
-                            print("Invalid value")
-                            continue
+                            if value <= 0:
+                                print("Invalid value")
+                                continue
 
-                        confirm = (await ainput(f'Is "{value}" correct? (y/N): ')).lower()
+                            confirm = (await ainput(f'Is "{value}" correct? (y/N): ')).lower()
 
-                        if confirm == "y":
-                            await self.storage.api_id(value)
-                            break
-                    except Exception as e:
-                        print(e)
+                            if confirm == "y":
+                                await self.storage.api_id(value)
+                                break
+                        except Exception as e:
+                            print(e)
 
     def load_plugins(self):
         if self.plugins:
@@ -726,22 +726,31 @@ class Client(Methods):
     async def handle_download(self, packet):
         file_id, directory, file_name, in_memory, file_size, progress, progress_args = packet
 
-        file = BytesIO() if in_memory else tempfile.NamedTemporaryFile("wb", delete=False)
+        os.makedirs(directory, exist_ok=True)
+        temp_file_path = os.path.abspath(re.sub("\\\\", "/", os.path.join(directory, file_name))) + ".temp"
+        file = BytesIO() if in_memory else open(temp_file_path, "wb")
 
-        async for chunk in self.get_file(file_id, file_size, 0, 0, progress, progress_args):
-            file.write(chunk)
+        try:
+            async for chunk in self.get_file(file_id, file_size, 0, 0, progress, progress_args):
+                file.write(chunk)
+        except BaseException as e:
+            if not in_memory:
+                file.close()
+                os.remove(temp_file_path)
 
-        if file and not in_memory:
-            file_path = os.path.abspath(re.sub("\\\\", "/", os.path.join(directory, file_name)))
-            os.makedirs(directory, exist_ok=True)
-            file.close()
-            shutil.move(file.name, file_path)
+            if isinstance(e, asyncio.CancelledError):
+                raise e
 
-            return file_path
-
-        if file and in_memory:
-            file.name = file_name
-            return file
+            return None
+        else:
+            if in_memory:
+                file.name = file_name
+                return file
+            else:
+                file.close()
+                file_path = os.path.splitext(temp_file_path)[0]
+                shutil.move(temp_file_path, file_path)
+                return file_path
 
     async def get_file(
         self,
@@ -968,9 +977,10 @@ class Client(Methods):
                             break
                 except Exception as e:
                     raise e
+        except pyrogram.StopTransmission:
+            raise
         except Exception as e:
-            if not isinstance(e, pyrogram.StopTransmission):
-                log.error(e, exc_info=True)
+            log.error(e, exc_info=True)
 
     def guess_mime_type(self, filename: str) -> Optional[str]:
         return self.mimetypes.guess_type(filename)[0]
